==> bonita-server-8.0.0-sources.jar: org/bonitasoft/engine/service/ProcessEngineServicesResolver.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.service;

import org.bonitasoft.engine.service.impl.ServiceAccessorFactory;

/**
 * @author Baptiste Mesta
 */
public class ProcessEngineServicesResolver implements ServicesLookup {

    @Override
    public <T> T lookupOnPlatform(String serviceName) {
        try {
            PlatformServiceAccessor platformServiceAccessor = ServiceAccessorFactory.getInstance()
                    .createPlatformServiceAccessor();
            return platformServiceAccessor.lookup(serviceName);
        } catch (Exception e) {
            throw new IllegalStateException("Unable to find the service " + serviceName, e);
        }
    }

    @Override
    public <T> T lookupOnTenant(Long tenantId, final String serviceName) {
        if (tenantId == null) {
            return lookupOnPlatform(serviceName);
        }
        try {
            TenantServiceAccessor instance = TenantServiceSingleton.getInstance();
            return instance.lookup(serviceName);
        } catch (Exception e) {
            throw new IllegalStateException("Unable to find the service " + serviceName, e);
        }
    }
}

==> bonita-server-9.0.0-sources.jar: org/bonitasoft/engine/service/ProcessEngineServicesResolver.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.service;

import org.bonitasoft.engine.service.impl.ServiceAccessorFactory;

/**
 * @author Baptiste Mesta
 */
public class ProcessEngineServicesResolver implements ServicesLookup {

    @Override
    public <T> T lookupOnPlatform(String serviceName) {
        try {
            return ServiceAccessorFactory.getInstance().createServiceAccessor().lookup(serviceName);
        } catch (Exception e) {
            throw new IllegalStateException("Unable to find the service " + serviceName, e);
        }
    }

    @Override
    public <T> T lookupOnTenant(Long tenantId, final String serviceName) {
        if (tenantId == null) {
            return lookupOnPlatform(serviceName);
        }
        try {
            return ServiceAccessorSingleton.getInstance().lookup(serviceName);
        } catch (Exception e) {
            throw new IllegalStateException("Unable to find the service " + serviceName, e);
        }
    }
}
